package fi.hsivonen.photobackup;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

public class NotInSetFilter extends
        RootlessRestResponseContentHandlerFilter {

    private final int page;
    
    private boolean fetchNextPage = false;
    
    private final FlickrEntityResolver resolver;

    private final Set<String> photoids;
    
    public NotInSetFilter(int page, FlickrEntityResolver resolver, Set<String> photoids) {
        super(new DefaultHandler());
        this.page = page;
        this.resolver = resolver;
        this.photoids = photoids;
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#endElement(java.lang.String, java.lang.String, java.lang.String)
     */
    @Override
    public void endElement(String uri, String localName, String qName) throws SAXException {
        if (uri == "" && localName == "photos" && fetchNextPage) {
            // dirty, dirty tail recursion
            Map<String, Object> arguments = new HashMap<String, Object>();
            arguments.put("page", new Integer(page + 1));
            arguments.put("per_page", new Integer(500));
            System.out.println("Retrieving page " + (page + 1) + " of photos not in set");
            resolver.callApi(new NotInSetFilter(page + 1, resolver, photoids), "flickr.photos.getNotInSet", arguments);
        }
        super.endElement(uri, localName, qName);
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#startElement(java.lang.String, java.lang.String, java.lang.String, org.xml.sax.Attributes)
     */
    @Override
    public void startElement(String uri, String localName, String qName,
            Attributes atts) throws SAXException {
        if (uri == "" && localName == "photos") {
            fetchNextPage = (page < Integer.parseInt(atts.getValue("", "pages")));
        } else if (uri == "" && localName == "photo") {
                photoids.add(atts.getValue("", "id"));
        }
        super.startElement(uri, localName, qName, atts);
    }

    
    
}
